@@ -20,14 +20,40 @@ from typing import List
 from ..model.component import Component
 
 
+class ParserWarning:
+    _item: str
+    _warning: str
+
+    def __init__(self, item: str, warning: str):
+        self._item = item
+        self._warning = warning
+
+    def get_item(self) -> str:
+        return self._item
+
+    def get_warning_message(self) -> str:
+        return self._warning
+
+    def __repr__(self):
+        return '<ParserWarning item=\'{}\'>'.format(self._item)
+
+
 class BaseParser(ABC):
     _components: List[Component] = []
+    _warnings: List[ParserWarning] = []
 
     def __init__(self):
         self._components.clear()
+        self._warnings.clear()
 
     def component_count(self) -> int:
         return len(self._components)
 
     def get_components(self) -> List[Component]:
         return self._components
+
+    def get_warnings(self) -> List[ParserWarning]:
+        return self._warnings
+
+    def has_warnings(self) -> bool:
+        return len(self._warnings) > 0
